@@ -1,28 +1,19 @@
 /*
  * icons.[ch] written by Paolo Bacchilega, who writes:
- * "There is no problem for me, you can license my code under whatever licence you wish :)"
+ * "There is no problem for me, you can license my code
+ * under whatever licence you wish :)"
  *
- * $Id: icons.c 11284 2010-10-01 20:22:51Z charles $
+ * $Id: icons.c 12639 2011-08-07 18:41:13Z jordan $
  */
 
 #include <string.h> /* strcmp */
 #include <glib.h>
 #include <gtk/gtk.h>
+#include <gio/gio.h>
 #include "icons.h"
 
-#ifdef HAVE_GIO
- #if GTK_CHECK_VERSION( 2, 12, 0 )
-   #define USE_GIO_ICONS
- #endif
-#endif
-
-#ifdef USE_GIO_ICONS
- #include <gio/gio.h>
-#endif
-
 #define VOID_PIXBUF_KEY "void-pixbuf"
 
-#ifdef USE_GIO_ICONS
 static const char *
 get_static_string( const char *s )
 {
@@ -36,8 +27,6 @@ get_static_string( const char *s )
 
     return g_string_chunk_insert_const( static_strings, s );
 }
-#endif
-
 
 typedef struct {
     GtkIconTheme * icon_theme;
@@ -97,7 +86,6 @@ icon_cache_new (GtkWidget * for_widget, int icon_size)
     return icon_cache;
 }
 
-#ifdef USE_GIO_ICONS
 static const char *
 _icon_cache_get_icon_key( GIcon * icon )
 {
@@ -221,44 +209,10 @@ icon_cache_get_mime_type_icon( IconCache * icon_cache, const char * mime_type )
     return pixbuf;
 }
 
-#else /* USE_GIO_ICONS */
-
-static GdkPixbuf *
-icon_cache_get_mime_type_icon( IconCache * icon_cache, const char * mime_type )
-{
-    GdkPixbuf  * pixbuf;
-    const char * stock_name;
-
-    if( !strcmp( mime_type, UNKNOWN_MIME_TYPE ) )
-        stock_name = GTK_STOCK_MISSING_IMAGE;
-    else if( !strcmp( mime_type, DIRECTORY_MIME_TYPE ) )
-        stock_name = GTK_STOCK_DIRECTORY;
-    else
-        stock_name = GTK_STOCK_FILE;
-
-    pixbuf = g_hash_table_lookup( icon_cache->cache, stock_name );
-
-    if( pixbuf != NULL )
-    {
-        g_object_ref( pixbuf );
-        return pixbuf;
-    }
-
-    pixbuf = gtk_icon_theme_load_icon( icon_cache->icon_theme,
-                                       stock_name,
-                                       icon_cache->icon_size,
-                                       0, NULL );
-    g_hash_table_insert( icon_cache->cache, (gpointer) stock_name, g_object_ref( pixbuf ));
-    return pixbuf;
-}
-
-#endif
-
-
 GdkPixbuf *
-get_mime_type_icon( const char   * mime_type,
-                    GtkIconSize    icon_size,
-                    GtkWidget    * for_widget )
+gtr_get_mime_type_icon( const char   * mime_type,
+                        GtkIconSize    icon_size,
+                        GtkWidget    * for_widget )
 {
     int n;
 
@@ -280,14 +234,10 @@ get_mime_type_icon( const char   * mime_type,
 
 
 const char *
-get_mime_type_from_filename( const char * file G_GNUC_UNUSED )
+gtr_get_mime_type_from_filename( const char * file G_GNUC_UNUSED )
 {
-#ifdef USE_GIO_ICONS
     char * tmp = g_content_type_guess( file, NULL, 0, NULL );
     const char * ret = get_static_string( tmp );
     g_free( tmp );
     return ret;
-#else
-    return "uncertain";
-#endif
 }
