@@ -1,22 +1,24 @@
 /*
- * This file Copyright (C) 2009-2010 Mnemosyne LLC
+ * This file Copyright (C) Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2.  Works owned by the
+ * This file is licensed by the GPL version 2. Works owned by the
  * Transmission project are granted a special exemption to clause 2(b)
  * so that the bulk of its code can remain under the MIT license.
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: torrent-magnet.c 11301 2010-10-11 21:44:46Z charles $
+ * $Id: torrent-magnet.c 12589 2011-07-25 22:30:56Z jordan $
  */
 
 #include <assert.h>
-#include <event.h> /* struct evbuffer */
 #include <stdio.h> /* remove() */
+#include <string.h> /* memcpy(), memset(), memcmp() */
+
+#include <event2/buffer.h>
 
 #include "transmission.h"
 #include "bencode.h"
-#include "crypto.h"
+#include "crypto.h" /* tr_sha1() */
 #include "magnet.h"
 #include "metainfo.h"
 #include "resume.h"
@@ -137,7 +139,7 @@ ensureInfoDictOffsetIsCached( tr_torrent * tor )
     if( !tor->infoDictOffsetIsCached )
     {
         tor->infoDictOffset = findInfoDictOffset( tor );
-        tor->infoDictOffsetIsCached = TRUE;
+        tor->infoDictOffsetIsCached = true;
     }
 }
 
@@ -230,9 +232,9 @@ tr_torrentSetMetadataPiece( tr_torrent  * tor, int piece, const void  * data, in
     /* are we done? */
     if( m->piecesNeededCount == 0 )
     {
-        tr_bool success = FALSE;
-        tr_bool checksumPassed = FALSE;
-        tr_bool metainfoParsed = FALSE;
+        bool success = false;
+        bool checksumPassed = false;
+        bool metainfoParsed = false;
         uint8_t sha1[SHA_DIGEST_LENGTH];
 
         /* we've got a complete set of metainfo... see if it passes the checksum test */
@@ -252,7 +254,7 @@ tr_torrentSetMetadataPiece( tr_torrent  * tor, int piece, const void  * data, in
 
                 if( !tr_bencLoadFile( &newMetainfo, TR_FMT_BENC, path ) )
                 {
-                    tr_bool hasInfo;
+                    bool hasInfo;
                     tr_info info;
                     int infoDictLength;
 
@@ -269,7 +271,7 @@ tr_torrentSetMetadataPiece( tr_torrent  * tor, int piece, const void  * data, in
                     if( success && !tr_getBlockSize( info.pieceSize ) )
                     {
                         tr_torrentSetLocalError( tor, "%s", _( "Magnet torrent's metadata is not usable" ) );
-                        success = FALSE;
+                        success = false;
                     }
 
                     if( success )
@@ -315,10 +317,10 @@ tr_torrentSetMetadataPiece( tr_torrent  * tor, int piece, const void  * data, in
     }
 }
 
-tr_bool
+bool
 tr_torrentGetNextMetadataRequest( tr_torrent * tor, time_t now, int * setme_piece )
 {
-    tr_bool have_request = FALSE;
+    bool have_request = false;
     struct tr_incomplete_metadata * m;
 
     assert( tr_isTorrent( tor ) );
@@ -342,7 +344,7 @@ tr_torrentGetNextMetadataRequest( tr_torrent * tor, time_t now, int * setme_piec
 
         dbgmsg( tor, "next piece to request: %d", piece );
         *setme_piece = piece;
-        have_request = TRUE;
+        have_request = true;
     }
 
     return have_request;
@@ -357,7 +359,7 @@ tr_torrentGetMetadataPercent( const tr_torrent * tor )
         ret = 1.0;
     else {
         const struct tr_incomplete_metadata * m = tor->incompleteMetadata;
-        if( m == NULL )
+        if( !m || !m->pieceCount )
             ret = 0.0;
         else
             ret = (m->pieceCount - m->piecesNeededCount) / (double)m->pieceCount;
@@ -370,7 +372,6 @@ char*
 tr_torrentGetMagnetLink( const tr_torrent * tor )
 {
     int i;
-    char * ret;
     const char * name;
     struct evbuffer * s;
 
@@ -382,15 +383,13 @@ tr_torrentGetMagnetLink( const tr_torrent * tor )
     if( name && *name )
     {
         evbuffer_add_printf( s, "%s", "&dn=" );
-        tr_http_escape( s, tr_torrentName( tor ), -1, TRUE );
+        tr_http_escape( s, tr_torrentName( tor ), -1, true );
     }
     for( i=0; i<tor->info.trackerCount; ++i )
     {
         evbuffer_add_printf( s, "%s", "&tr=" );
-        tr_http_escape( s, tor->info.trackers[i].announce, -1, TRUE );
+        tr_http_escape( s, tor->info.trackers[i].announce, -1, true );
     }
 
-    ret = tr_strndup( EVBUFFER_DATA( s ), EVBUFFER_LENGTH( s ) );
-    evbuffer_free( s );
-    return ret;
+    return evbuffer_free_to_str( s );
 }
