@@ -1,16 +1,16 @@
 /*
  * Copyright (c) 2009-2010 by Juliusz Chroboczek
- * 
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
  * in the Software without restriction, including without limitation the rights
  * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  * copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
- * 
+ *
  * The above copyright notice and this permission notice shall be included in
  * all copies or substantial portions of the Software.
- * 
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -19,13 +19,15 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  * THE SOFTWARE.
  *
- * $Id: tr-dht.c 12033 2011-02-24 15:42:04Z jordan $
+ * $Id: tr-dht.c 12587 2011-07-25 21:30:46Z jch $
  *
  */
 
 /* ansi */
 #include <errno.h>
 #include <stdio.h>
+#include <string.h> /* memcpy(), memset(), memchr(), strlen() */
+#include <stdlib.h> /* atoi() */
 
 /* posix */
 #include <signal.h> /* sig_atomic_t */
@@ -148,7 +150,7 @@ dht_bootstrap(void *closure)
         return;
 
     if(cl->len > 0)
-        tr_ninf( "DHT", "Bootstrapping from %d nodes", num );
+        tr_ninf( "DHT", "Bootstrapping from %d IPv4 nodes", num );
 
     if(cl->len6 > 0)
         tr_ninf( "DHT", "Bootstrapping from %d IPv6 nodes", num6 );
@@ -225,6 +227,7 @@ dht_bootstrap(void *closure)
                 if(bootstrap_done(cl->session, 0))
                     break;
             }
+            fclose( f );
         }
 
         tr_free( bootstrap_file );
@@ -260,7 +263,7 @@ tr_dhtInit(tr_session *ss)
 {
     tr_benc benc;
     int rc;
-    tr_bool have_id = FALSE;
+    bool have_id = false;
     char * dat_file;
     uint8_t * nodes = NULL, * nodes6 = NULL;
     const uint8_t * raw;
@@ -268,7 +271,7 @@ tr_dhtInit(tr_session *ss)
     struct bootstrap_closure * cl;
 
     if( session ) /* already initialized */
-        return -1;    
+        return -1;
 
     tr_ndbg( "DHT", "Initializing DHT" );
 
@@ -342,8 +345,10 @@ tr_dhtUninit(tr_session *ss)
 
     tr_ndbg( "DHT", "Uninitializing DHT" );
 
-    event_free( dht_timer );
-    dht_timer = NULL;
+    if( dht_timer != NULL ) {
+        event_free( dht_timer );
+        dht_timer = NULL;
+    }
 
     /* Since we only save known good nodes, avoid erasing older data if we
        don't know enough nodes. */
@@ -390,7 +395,7 @@ tr_dhtUninit(tr_session *ss)
     session = NULL;
 }
 
-tr_bool
+bool
 tr_dhtEnabled( const tr_session * ss )
 {
     return ss && ( ss == session );
@@ -456,7 +461,7 @@ int
 tr_dhtAddNode( tr_session       * ss,
                const tr_address * address,
                tr_port            port,
-               tr_bool            bootstrap )
+               bool            bootstrap )
 {
     int af = address->type == TR_AF_INET ? AF_INET : AF_INET6;
 
@@ -524,9 +529,9 @@ callback( void *ignore UNUSED, int event,
             for( i=0; i<n; ++i )
                 tr_peerMgrAddPex( tor, TR_PEER_FROM_DHT, pex+i, -1 );
             tr_free(pex);
-            tr_tordbg(tor, "Learned %d%s peers from DHT",
+            tr_tordbg(tor, "Learned %d %s peers from DHT",
                       (int)n,
-                      event == DHT_EVENT_VALUES6 ? " IPv6" : "");
+                      event == DHT_EVENT_VALUES6 ? "IPv6" : "IPv4");
         }
         tr_sessionUnlock( session );
     } else if( event == DHT_EVENT_SEARCH_DONE ||
@@ -534,7 +539,7 @@ callback( void *ignore UNUSED, int event,
         tr_torrent * tor = tr_torrentFindFromHash( session, info_hash );
         if( tor ) {
             if( event == DHT_EVENT_SEARCH_DONE ) {
-                tr_torinf(tor, "DHT announce done");
+                tr_torinf(tor, "IPv4 DHT announce done");
                 tor->dhtAnnounceInProgress = 0;
             } else {
                 tr_torinf(tor, "IPv6 DHT announce done");
@@ -544,8 +549,8 @@ callback( void *ignore UNUSED, int event,
     }
 }
 
-int
-tr_dhtAnnounce(tr_torrent *tor, int af, tr_bool announce)
+static int
+tr_dhtAnnounce(tr_torrent *tor, int af, bool announce)
 {
     int rc, status, numnodes, ret = 0;
 
@@ -564,29 +569,60 @@ tr_dhtAnnounce(tr_torrent *tor, int af, tr_bool announce)
                          announce ? tr_sessionGetPeerPort(session) : 0,
                          af, callback, NULL);
         if( rc >= 1 ) {
-            tr_torinf(tor, "Starting%s DHT announce (%s, %d nodes)",
-                      af == AF_INET6 ? " IPv6" : "",
+            tr_torinf(tor, "Starting %s DHT announce (%s, %d nodes)",
+                      af == AF_INET6 ? "IPv6" : "IPv4",
                       tr_dhtPrintableStatus(status), numnodes);
             if(af == AF_INET)
-                tor->dhtAnnounceInProgress = TRUE;
+                tor->dhtAnnounceInProgress = true;
             else
-                tor->dhtAnnounce6InProgress = TRUE;
+                tor->dhtAnnounce6InProgress = true;
             ret = 1;
         } else {
-            tr_torerr(tor, "%sDHT announce failed (%s, %d nodes): %s",
-                      af == AF_INET6 ? "IPv6 " : "",
+            tr_torerr(tor, "%s DHT announce failed (%s, %d nodes): %s",
+                      af == AF_INET6 ? "IPv6" : "IPv4",
                       tr_dhtPrintableStatus(status), numnodes,
                       tr_strerror( errno ) );
         }
     } else {
-        tr_tordbg(tor, "%sDHT not ready (%s, %d nodes)",
-                  af == AF_INET6 ? "IPv6 " : "",
+        tr_tordbg(tor, "%s DHT not ready (%s, %d nodes)",
+                  af == AF_INET6 ? "IPv6" : "IPv4",
                   tr_dhtPrintableStatus(status), numnodes);
     }
 
     return ret;
 }
 
+void
+tr_dhtUpkeep( tr_session * session )
+{
+    tr_torrent * tor = NULL;
+    const time_t now = tr_time( );
+
+    while(( tor = tr_torrentNext( session, tor )))
+    {
+        if( !tor->isRunning || !tr_torrentAllowsDHT( tor ) )
+            continue;
+
+        if( tor->dhtAnnounceAt <= now )
+        {
+            const int rc = tr_dhtAnnounce(tor, AF_INET, 1);
+
+            tor->dhtAnnounceAt = now + ((rc == 0)
+                                     ? 5 + tr_cryptoWeakRandInt( 5 )
+                                     : 25 * 60 + tr_cryptoWeakRandInt( 3*60 ));
+        }
+
+        if( tor->dhtAnnounce6At <= now )
+        {
+            const int rc = tr_dhtAnnounce(tor, AF_INET6, 1);
+
+            tor->dhtAnnounce6At = now + ((rc == 0)
+                                      ? 5 + tr_cryptoWeakRandInt( 5 )
+                                      : 25 * 60 + tr_cryptoWeakRandInt( 3*60 ));
+        }
+    }
+}
+
 void
 tr_dhtCallback(unsigned char *buf, int buflen,
                struct sockaddr *from, socklen_t fromlen,
@@ -624,6 +660,17 @@ timer_callback(int s UNUSED, short type UNUSED, void *session )
     tr_dhtCallback(NULL, 0, NULL, 0, session);
 }
 
+/* This function should return true when a node is blacklisted.  We do
+   not support using a blacklist with the DHT in Transmission, since
+   massive (ab)use of this feature could harm the DHT.  However, feel
+   free to add support to your private copy as long as you don't
+   redistribute it. */
+
+int
+dht_blacklisted(const struct sockaddr *sa UNUSED, int salen UNUSED)
+{
+    return 0;
+}
 
 void
 dht_hash(void *hash_return, int hash_size,
