@@ -45,61 +45,101 @@ static int test = 0;
     }
 #endif
 
+static int
+test_bitfield_count_range( void )
+{
+    int i;
+    int n;
+    int begin;
+    int end;
+    int count1;
+    int count2;
+    const int bitCount = 100 + tr_cryptoWeakRandInt( 1000 );
+    tr_bitfield bf;
+
+    /* generate a random bitfield */
+    tr_bitfieldConstruct( &bf, bitCount );
+    for( i=0, n=tr_cryptoWeakRandInt(bitCount); i<n; ++i )
+        tr_bitfieldAdd( &bf, tr_cryptoWeakRandInt(bitCount) );
+
+    begin = tr_cryptoWeakRandInt( bitCount );
+    do {
+        end = tr_cryptoWeakRandInt( bitCount );
+    } while( end == begin );
+    if( end < begin ) {
+        const int tmp = begin;
+        begin = end;
+        end = tmp;
+    }
+
+    count1 = 0;
+    for( i=begin; i<end; ++i )
+        if( tr_bitfieldHas( &bf, i ) )
+            ++count1;
+    count2 = tr_bitfieldCountRange( &bf, begin, end );
+    check( count1 == count2 );
+
+    tr_bitfieldDestruct( &bf );
+    return 0;
+}
+
 static int
 test_bitfields( void )
 {
     unsigned int  i;
-    unsigned int  bitcount = 5000000;
-    tr_bitfield * field = tr_bitfieldNew( bitcount );
+    unsigned int  bitcount = 500;
+    tr_bitfield field;
+
+    tr_bitfieldConstruct( &field, bitcount );
 
     /* test tr_bitfieldAdd */
     for( i = 0; i < bitcount; ++i )
         if( !( i % 7 ) )
-            tr_bitfieldAdd( field, i );
+            tr_bitfieldAdd( &field, i );
     for( i = 0; i < bitcount; ++i )
-        check( tr_bitfieldHas( field, i ) == ( !( i % 7 ) ) );
+        check( tr_bitfieldHas( &field, i ) == ( !( i % 7 ) ) );
 
     /* test tr_bitfieldAddRange */
-    tr_bitfieldAddRange( field, 0, bitcount );
+    tr_bitfieldAddRange( &field, 0, bitcount );
     for( i = 0; i < bitcount; ++i )
-        check( tr_bitfieldHas( field, i ) );
+        check( tr_bitfieldHas( &field, i ) );
 
     /* test tr_bitfieldRemRange in the middle of a boundary */
-    tr_bitfieldRemRange( field, 4, 21 );
+    tr_bitfieldRemRange( &field, 4, 21 );
     for( i = 0; i < 64; ++i )
-        check( tr_bitfieldHas( field, i ) == ( ( i < 4 ) || ( i >= 21 ) ) );
+        check( tr_bitfieldHas( &field, i ) == ( ( i < 4 ) || ( i >= 21 ) ) );
 
     /* test tr_bitfieldRemRange on the boundaries */
-    tr_bitfieldAddRange( field, 0, 64 );
-    tr_bitfieldRemRange( field, 8, 24 );
+    tr_bitfieldAddRange( &field, 0, 64 );
+    tr_bitfieldRemRange( &field, 8, 24 );
     for( i = 0; i < 64; ++i )
-        check( tr_bitfieldHas( field, i ) == ( ( i < 8 ) || ( i >= 24 ) ) );
+        check( tr_bitfieldHas( &field, i ) == ( ( i < 8 ) || ( i >= 24 ) ) );
 
     /* test tr_bitfieldRemRange when begin & end is on the same word */
-    tr_bitfieldAddRange( field, 0, 64 );
-    tr_bitfieldRemRange( field, 4, 5 );
+    tr_bitfieldAddRange( &field, 0, 64 );
+    tr_bitfieldRemRange( &field, 4, 5 );
     for( i = 0; i < 64; ++i )
-        check( tr_bitfieldHas( field, i ) == ( ( i < 4 ) || ( i >= 5 ) ) );
+        check( tr_bitfieldHas( &field, i ) == ( ( i < 4 ) || ( i >= 5 ) ) );
 
     /* test tr_bitfieldAddRange */
-    tr_bitfieldRemRange( field, 0, 64 );
-    tr_bitfieldAddRange( field, 4, 21 );
+    tr_bitfieldRemRange( &field, 0, 64 );
+    tr_bitfieldAddRange( &field, 4, 21 );
     for( i = 0; i < 64; ++i )
-        check( tr_bitfieldHas( field, i ) == ( ( 4 <= i ) && ( i < 21 ) ) );
+        check( tr_bitfieldHas( &field, i ) == ( ( 4 <= i ) && ( i < 21 ) ) );
 
     /* test tr_bitfieldAddRange on the boundaries */
-    tr_bitfieldRemRange( field, 0, 64 );
-    tr_bitfieldAddRange( field, 8, 24 );
+    tr_bitfieldRemRange( &field, 0, 64 );
+    tr_bitfieldAddRange( &field, 8, 24 );
     for( i = 0; i < 64; ++i )
-        check( tr_bitfieldHas( field, i ) == ( ( 8 <= i ) && ( i < 24 ) ) );
+        check( tr_bitfieldHas( &field, i ) == ( ( 8 <= i ) && ( i < 24 ) ) );
 
     /* test tr_bitfieldAddRange when begin & end is on the same word */
-    tr_bitfieldRemRange( field, 0, 64 );
-    tr_bitfieldAddRange( field, 4, 5 );
+    tr_bitfieldRemRange( &field, 0, 64 );
+    tr_bitfieldAddRange( &field, 4, 5 );
     for( i = 0; i < 64; ++i )
-        check( tr_bitfieldHas( field, i ) == ( ( 4 <= i ) && ( i < 5 ) ) );
+        check( tr_bitfieldHas( &field, i ) == ( ( 4 <= i ) && ( i < 5 ) ) );
 
-    tr_bitfieldFree( field );
+    tr_bitfieldDestruct( &field );
     return 0;
 }
 
@@ -261,16 +301,16 @@ test_lowerbound( void )
     int i;
     const int A[] = { 1, 2, 3, 3, 3, 5, 8 };
     const int expected_pos[] = { 0, 1, 2, 5, 5, 6, 6, 6, 7, 7 };
-    const int expected_exact[] = { TRUE, TRUE, TRUE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE };
+    const int expected_exact[] = { true, true, true, false, true, false, false, true, false, false };
     const int N = sizeof(A) / sizeof(A[0]);
 
     for( i=1; i<=10; ++i )
     {
-        tr_bool exact;
+        bool exact;
         const int pos = tr_lowerBound( &i, A, N, sizeof(int), compareInts, &exact );
 
 #if 0
-        fprintf( stderr, "searching for %d.  ", i );
+        fprintf( stderr, "searching for %d. ", i );
         fprintf( stderr, "result: index = %d, ", pos );
         if( pos != N )
             fprintf( stderr, "A[%d] == %d\n", pos, A[pos] );
@@ -293,9 +333,6 @@ test_memmem( void )
     check( tr_memmem( haystack, sizeof haystack, haystack, sizeof haystack) == haystack )
     check( tr_memmem( haystack, sizeof haystack, needle, sizeof needle) == haystack + 2 )
     check( tr_memmem( needle, sizeof needle, haystack, sizeof haystack) == NULL )
-    check( tr_memmem( haystack, sizeof haystack, "", 0) == haystack )
-    check( tr_memmem( haystack, sizeof haystack, NULL, 0) == haystack )
-    check( tr_memmem( haystack, 0, "", 0) == haystack )
 
     return 0;
 }
@@ -348,6 +385,16 @@ test_url( void )
     char * str;
     const char * url;
 
+    url = "http://1";
+    check( !tr_urlParse( url, -1, &scheme, &host, &port, &path ) );
+    check( !strcmp( scheme, "http" ) )
+    check( !strcmp( host, "1" ) )
+    check( !strcmp( path, "/" ) )
+    check( port == 80 )
+    tr_free( scheme );
+    tr_free( path );
+    tr_free( host );
+
     url = "http://www.some-tracker.org/some/path";
     check( !tr_urlParse( url, -1, &scheme, &host, &port, &path ) )
     check( !strcmp( scheme, "http" ) )
@@ -404,11 +451,20 @@ test_truncd( void )
     check( !strcmp( buf, "3" ) );
 
     tr_snprintf( buf, sizeof( buf ), "%.2f", tr_truncd( nan, 2 ) );
-    check( !strcmp( buf, "nan" ) );
+    check( strstr( buf, "nan" ) != NULL );
 
     return 0;
 }
 
+struct blah
+{
+    uint8_t  hash[SHA_DIGEST_LENGTH];  /* pieces hash */
+    int8_t   priority;                 /* TR_PRI_HIGH, _NORMAL, or _LOW */
+    int8_t   dnd;                      /* "do not download" flag */
+    time_t   timeChecked;              /* the last time we tested this piece */
+};
+
+
 int
 main( void )
 {
@@ -420,8 +476,8 @@ main( void )
     /* base64 */
     out = tr_base64_encode( "YOYO!", -1, &len );
     check( out );
-    check( !strcmp( out, "WU9ZTyE=\n" ) );
-    check( len == 9 );
+    check( !strcmp( out, "WU9ZTyE=" ) );
+    check( len == 8 );
     in = tr_base64_decode( out, -1, &len );
     check( in );
     check( !strcmp( in, "YOYO!" ) );
@@ -468,6 +524,11 @@ main( void )
         if( ( i = test_bitfields( ) ) )
             return i;
 
+    /* bitfield count range */
+    for( l=0; l<10000; ++l )
+        if(( i = test_bitfield_count_range( )))
+            return i;
+
     return 0;
 }
 
