@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: FileOutlineController.m 12994 2011-10-19 01:56:06Z livings124 $
+ * $Id: FileOutlineController.m 13251 2012-03-13 02:52:11Z livings124 $
  *
- * Copyright (c) 2008-2011 Transmission authors and contributors
+ * Copyright (c) 2008-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -32,8 +32,6 @@
 #import "NSStringAdditions.h"
 #import <Quartz/Quartz.h>
 
-#import "utils.h"
-
 #define ROW_SMALL_HEIGHT 18.0
 
 typedef enum
@@ -53,7 +51,7 @@ typedef enum
 
 - (NSMenu *) menu;
 
-- (NSUInteger) findFileNode: (FileListNode *) node inList: (NSArray *) list inRange: (NSRange) range currentParent: (FileListNode *) currentParent finalParent: (FileListNode **) parent;
+- (NSUInteger) findFileNode: (FileListNode *) node inList: (NSArray *) list atIndexes: (NSIndexSet *) range currentParent: (FileListNode *) currentParent finalParent: (FileListNode **) parent;
 
 @end
 
@@ -72,9 +70,6 @@ typedef enum
     
     [fOutline setMenu: [self menu]];
     
-    //fLock = [[NSRecursiveLock alloc] init];
-    [fLock setName: @"File Table"];
-    
     [self setTorrent: nil];
 }
 
@@ -83,8 +78,6 @@ typedef enum
     [fFileList release];
     [fFilterText release];
     
-    [fLock release];
-    
     [super dealloc];
 }
 
@@ -102,13 +95,8 @@ typedef enum
     [fFilterText release];
     fFilterText = nil;
     
-    /*while (![fLock tryLock])
-        tr_wait_msec(100);*/
-    
     [fOutline reloadData];
-    [fOutline deselectAll: nil];
-    
-    [fLock unlock];
+    [fOutline deselectAll: nil]; //do this after reloading the data #4575
 }
 
 - (void) setFilterText: (NSString *) text
@@ -125,16 +113,8 @@ typedef enum
     
     const BOOL onLion = [NSApp isOnLionOrBetter];
     
-    /*while (![fLock tryLock])
-        tr_wait_msec(100);*/
-    
     if (onLion)
-    {
-        [[NSAnimationContext currentContext] setCompletionHandler: nil];
-        [NSAnimationContext beginGrouping];
-        
         [fOutline beginUpdates];
-    }
     
     NSUInteger currentIndex = 0, totalCount = 0;
     NSMutableArray * itemsToAdd = [NSMutableArray array];
@@ -145,21 +125,22 @@ typedef enum
     NSArray * tempList = !text ? [fTorrent fileList] : [fTorrent flatFileList];
     for (FileListNode * item in tempList)
     {
-        BOOL filter = NO;
+        __block BOOL filter = NO;
         if (components)
         {
-            for (NSString * sub in components)
-                if ([[item name] rangeOfString: sub options: (NSCaseInsensitiveSearch | NSDiacriticInsensitiveSearch)].location == NSNotFound)
+            [components enumerateObjectsWithOptions: NSEnumerationConcurrent usingBlock: ^(id obj, NSUInteger idx, BOOL * stop) {
+                if ([[item name] rangeOfString: (NSString *)obj options: (NSCaseInsensitiveSearch | NSDiacriticInsensitiveSearch)].location == NSNotFound)
                 {
                     filter = YES;
-                    break;
+                    *stop = YES;
                 }
+            }];
         }
         
         if (!filter)
         {
             FileListNode * parent = nil;
-            NSUInteger previousIndex = ![item isFolder] ? [self findFileNode: item inList: fFileList inRange: NSMakeRange(currentIndex, [fFileList count]-currentIndex) currentParent: nil finalParent: &parent] : NSNotFound;
+            NSUInteger previousIndex = ![item isFolder] ? [self findFileNode: item inList: fFileList atIndexes: [NSIndexSet indexSetWithIndexesInRange: NSMakeRange(currentIndex, [fFileList count]-currentIndex)] currentParent: nil finalParent: &parent] : NSNotFound;
             
             if (previousIndex == NSNotFound)
             {
@@ -222,39 +203,25 @@ typedef enum
         [fOutline insertItemsAtIndexes: itemsToAddIndexes inParent: nil withAnimation: NSTableViewAnimationSlideUp];
     
     if (onLion)
-    {
         [fOutline endUpdates];
-        
-        [NSAnimationContext endGrouping];
-    }
     else
-    {
         [fOutline reloadData];
     
-        [fLock unlock];
-    }
-    
     [fFilterText release];
     fFilterText = [text retain];
 }
 
-- (void) reloadData
+- (void) refresh
 {
     [fTorrent updateFileStat];
     
-    /*while (![fLock tryLock])
-        tr_wait_msec(100);*/
-    
-    [fOutline reloadData];
-    
-    [fLock unlock];
+    [fOutline setNeedsDisplay: YES];
 }
 
 - (void) outlineViewSelectionDidChange: (NSNotification *) notification
 {
-    if ([NSApp isOnSnowLeopardOrBetter] && [QLPreviewPanelSL sharedPreviewPanelExists]
-        && [[QLPreviewPanelSL sharedPreviewPanel] isVisible])
-        [[QLPreviewPanelSL sharedPreviewPanel] reloadData];
+    if ([QLPreviewPanel sharedPreviewPanelExists] && [[QLPreviewPanel sharedPreviewPanel] isVisible])
+        [[QLPreviewPanel sharedPreviewPanel] reloadData];
 }
 
 - (NSInteger) outlineView: (NSOutlineView *) outlineView numberOfChildrenOfItem: (id) item
@@ -286,8 +253,7 @@ typedef enum
         return item;
 }
 
-- (void) outlineView: (NSOutlineView *) outlineView willDisplayCell: (id) cell
-            forTableColumn: (NSTableColumn *) tableColumn item: (id) item
+- (void) outlineView: (NSOutlineView *) outlineView willDisplayCell: (id) cell forTableColumn: (NSTableColumn *) tableColumn item: (id) item
 {
     NSString * identifier = [tableColumn identifier];
     if ([identifier isEqualToString: @"Check"])
@@ -302,20 +268,19 @@ typedef enum
     else;
 }
 
-- (void) outlineView: (NSOutlineView *) outlineView setObjectValue: (id) object
-        forTableColumn: (NSTableColumn *) tableColumn byItem: (id) item
+- (void) outlineView: (NSOutlineView *) outlineView setObjectValue: (id) object forTableColumn: (NSTableColumn *) tableColumn byItem: (id) item
 {
     NSString * identifier = [tableColumn identifier];
     if ([identifier isEqualToString: @"Check"])
     {
         NSIndexSet * indexSet;
-        if (([NSApp isOnSnowLeopardOrBetter] ? [NSEvent modifierFlags] : [[NSApp currentEvent] modifierFlags]) & NSAlternateKeyMask)
+        if ([NSEvent modifierFlags] & NSAlternateKeyMask)
             indexSet = [NSIndexSet indexSetWithIndexesInRange: NSMakeRange(0, [fTorrent fileCount])];
         else
             indexSet = [(FileListNode *)item indexes];
         
         [fTorrent setFileCheckState: [object intValue] != NSOffState ? NSOnState : NSOffState forIndexes: indexSet];
-        [fOutline reloadData];
+        [fOutline setNeedsDisplay: YES];
         
         [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateUI" object: nil];
     }
@@ -334,7 +299,7 @@ typedef enum
     {
         NSString * path = [fTorrent fileLocation: item];
         if (!path)
-            path = [[item path] stringByAppendingPathComponent: [item name]];
+            path = [[(FileListNode *)item path] stringByAppendingPathComponent: [(FileListNode *)item name]];
         return path;
     }
     else if ([ident isEqualToString: @"Check"])
@@ -386,9 +351,6 @@ typedef enum
 
 - (void) setCheck: (id) sender
 {
-    /*while (![fLock tryLock])
-        tr_wait_msec(100);*/
-    
     NSInteger state = [sender tag] == FILE_UNCHECK_TAG ? NSOffState : NSOnState;
     
     NSIndexSet * indexSet = [fOutline selectedRowIndexes];
@@ -397,16 +359,11 @@ typedef enum
         [itemIndexes addIndexes: [[fOutline itemAtRow: i] indexes]];
     
     [fTorrent setFileCheckState: state forIndexes: itemIndexes];
-    [fOutline reloadData];
-    
-    [fLock unlock];
+    [fOutline setNeedsDisplay: YES];
 }
 
 - (void) setOnlySelectedCheck: (id) sender
 {
-    /*while (![fLock tryLock])
-        tr_wait_msec(100);*/
-    
     NSIndexSet * indexSet = [fOutline selectedRowIndexes];
     NSMutableIndexSet * itemIndexes = [NSMutableIndexSet indexSet];
     for (NSInteger i = [indexSet firstIndex]; i != NSNotFound; i = [indexSet indexGreaterThanIndex: i])
@@ -418,9 +375,7 @@ typedef enum
     [remainingItemIndexes removeIndexes: itemIndexes];
     [fTorrent setFileCheckState: NSOffState forIndexes: remainingItemIndexes];
     
-    [fOutline reloadData];
-    
-    [fLock unlock];
+    [fOutline setNeedsDisplay: YES];
 }
 
 - (void) setPriority: (id) sender
@@ -438,50 +393,28 @@ typedef enum
             priority = TR_PRI_LOW;
     }
     
-    /*while (![fLock tryLock])
-        tr_wait_msec(100);*/
-    
     NSIndexSet * indexSet = [fOutline selectedRowIndexes];
     NSMutableIndexSet * itemIndexes = [NSMutableIndexSet indexSet];
     for (NSInteger i = [indexSet firstIndex]; i != NSNotFound; i = [indexSet indexGreaterThanIndex: i])
         [itemIndexes addIndexes: [[fOutline itemAtRow: i] indexes]];
     
     [fTorrent setFilePriority: priority forIndexes: itemIndexes];
-    [fOutline reloadData];
-    
-    [fLock unlock];
+    [fOutline setNeedsDisplay: YES];
 }
 
 - (void) revealFile: (id) sender
 {
-    /*while (![fLock tryLock])
-        tr_wait_msec(100);*/
-    
     NSIndexSet * indexes = [fOutline selectedRowIndexes];
-    if ([NSApp isOnSnowLeopardOrBetter])
+    NSMutableArray * paths = [NSMutableArray arrayWithCapacity: [indexes count]];
+    for (NSUInteger i = [indexes firstIndex]; i != NSNotFound; i = [indexes indexGreaterThanIndex: i])
     {
-        NSMutableArray * paths = [NSMutableArray arrayWithCapacity: [indexes count]];
-        for (NSUInteger i = [indexes firstIndex]; i != NSNotFound; i = [indexes indexGreaterThanIndex: i])
-        {
-            NSString * path = [fTorrent fileLocation: [fOutline itemAtRow: i]];
-            if (path)
-                [paths addObject: [NSURL fileURLWithPath: path]];
-        }
-        
-        if ([paths count])
-            [[NSWorkspace sharedWorkspace] activateFileViewerSelectingURLs: paths];
-    }
-    else
-    {
-        for (NSUInteger i = [indexes firstIndex]; i != NSNotFound; i = [indexes indexGreaterThanIndex: i])
-        {
-            NSString * path = [fTorrent fileLocation: [fOutline itemAtRow: i]];
-            if (path)
-                [[NSWorkspace sharedWorkspace] selectFile: path inFileViewerRootedAtPath: nil];
-        }
+        NSString * path = [fTorrent fileLocation: [fOutline itemAtRow: i]];
+        if (path)
+            [paths addObject: [NSURL fileURLWithPath: path]];
     }
     
-    [fLock unlock];
+    if ([paths count] > 0)
+        [[NSWorkspace sharedWorkspace] activateFileViewerSelectingURLs: paths];
 }
 
 #warning make real view controller (Leopard-only) so that Command-R will work
@@ -617,7 +550,7 @@ typedef enum
             action: @selector(setPriority:) keyEquivalent: @""];
     [item setTarget: self];
     [item setTag: FILE_PRIORITY_HIGH_TAG];
-    [item setImage: [NSImage imageNamed: @"PriorityHigh.png"]];
+    [item setImage: [NSImage imageNamed: @"PriorityHighTemplate.png"]];
     [priorityMenu addItem: item];
     [item release];
     
@@ -625,7 +558,7 @@ typedef enum
             action: @selector(setPriority:) keyEquivalent: @""];
     [item setTarget: self];
     [item setTag: FILE_PRIORITY_NORMAL_TAG];
-    [item setImage: [NSImage imageNamed: @"PriorityNormal.png"]];
+    [item setImage: [NSImage imageNamed: @"PriorityNormalTemplate.png"]];
     [priorityMenu addItem: item];
     [item release];
     
@@ -633,7 +566,7 @@ typedef enum
             action: @selector(setPriority:) keyEquivalent: @""];
     [item setTarget: self];
     [item setTag: FILE_PRIORITY_LOW_TAG];
-    [item setImage: [NSImage imageNamed: @"PriorityLow.png"]];
+    [item setImage: [NSImage imageNamed: @"PriorityLowTemplate.png"]];
     [priorityMenu addItem: item];
     [item release];
     
@@ -651,28 +584,34 @@ typedef enum
     return [menu autorelease];
 }
 
-- (NSUInteger) findFileNode: (FileListNode *) node inList: (NSArray *) list inRange: (NSRange) range currentParent: (FileListNode *) currentParent finalParent: (FileListNode **) parent
+- (NSUInteger) findFileNode: (FileListNode *) node inList: (NSArray *) list atIndexes: (NSIndexSet *) indexes currentParent: (FileListNode *) currentParent finalParent: (FileListNode **) parent
 {
     NSAssert(![node isFolder], @"Looking up folder node!");
     
-    const NSUInteger nodeIndex = [[node indexes] firstIndex];
-    for (NSUInteger index = range.location; index < NSMaxRange(range); ++index)
-    {
-        FileListNode * checkNode = [list objectAtIndex: index];
-        if ([checkNode isEqualTo: node])
-        {
-            *parent = currentParent;
-            return index;
-        }
-        else if ([checkNode isFolder] && [[checkNode indexes] containsIndex: nodeIndex])
-        {
-            const NSUInteger subIndex = [self findFileNode: node inList: [checkNode children] inRange: NSMakeRange(0, [[checkNode children] count]) currentParent: checkNode finalParent: parent];
-            NSAssert(subIndex != NSNotFound, @"We didn't find an expected file node.");
-            return subIndex;
-        }
-    }
+    __block NSUInteger retIndex = NSNotFound;
     
-    return NSNotFound;
+    [list enumerateObjectsAtIndexes: indexes options: NSEnumerationConcurrent usingBlock: ^(id checkNode, NSUInteger index, BOOL * stop) {
+        if ([[checkNode indexes] containsIndex: [[node indexes] firstIndex]])
+        {
+            if (![checkNode isFolder])
+            {
+                NSAssert2([checkNode isEqualTo: node], @"Expected file nodes to be equal: %@ %@", checkNode, node);
+                
+                *parent = currentParent;
+                retIndex = index;
+            }
+            else
+            {
+                const NSUInteger subIndex = [self findFileNode: node inList: [checkNode children] atIndexes: [NSIndexSet indexSetWithIndexesInRange: NSMakeRange(0, [[checkNode children] count])] currentParent: checkNode finalParent: parent];
+                NSAssert(subIndex != NSNotFound, @"We didn't find an expected file node.");
+                retIndex = subIndex;
+            }
+            
+            *stop = YES;
+        }
+    }];
+    
+    return retIndex;
 }
 
 @end
