@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: InfoFileViewController.h 11617 2011-01-01 20:42:14Z livings124 $
+ * $Id: InfoFileViewController.h 13162 2012-01-14 17:12:04Z livings124 $
  *
- * Copyright (c) 2010-2011 Transmission authors and contributors
+ * Copyright (c) 2010-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -23,6 +23,7 @@
  *****************************************************************************/
 
 #import <Cocoa/Cocoa.h>
+#import <Quartz/Quartz.h>
 #import "InfoViewController.h"
 
 @class FileOutlineController;
@@ -47,6 +48,6 @@
 
 - (NSArray *) quickLookURLs;
 - (BOOL) canQuickLook;
-- (NSRect) quickLookSourceFrameForPreviewItem: (id /*<QLPreviewItem>*/) item;
+- (NSRect) quickLookSourceFrameForPreviewItem: (id <QLPreviewItem>) item;
 
 @end
