@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: InfoPeersViewController.m 12081 2011-03-04 02:58:08Z livings124 $
+ * $Id: InfoPeersViewController.m 13251 2012-03-13 02:52:11Z livings124 $
  *
- * Copyright (c) 2010-2011 Transmission authors and contributors
+ * Copyright (c) 2010-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -580,11 +580,8 @@
     //sort by IP after primary sort
     if (useSecond)
     {
-        #warning when 10.6-only, replace with sortDescriptorWithKey:ascending:selector:
-        NSSortDescriptor * secondDescriptor = [[NSSortDescriptor alloc] initWithKey: @"IP" ascending: asc
-                                                                        selector: @selector(compareNumeric:)];
+        NSSortDescriptor * secondDescriptor = [NSSortDescriptor sortDescriptorWithKey: @"IP" ascending: asc selector: @selector(compareNumeric:)];
         [descriptors addObject: secondDescriptor];
-        [secondDescriptor release];
     }
     
     return descriptors;
