@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: TorrentCell.m 12850 2011-09-07 01:24:43Z livings124 $
+ * $Id: TorrentCell.m 13251 2012-03-13 02:52:11Z livings124 $
  *
- * Copyright (c) 2006-2011 Transmission authors and contributors
+ * Copyright (c) 2006-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -24,7 +24,7 @@
 
 #import "TorrentCell.h"
 #import "GroupsController.h"
-#import "NSApplicationAdditions.h"
+#import "NSImageAdditions.h"
 #import "NSStringAdditions.h"
 #import "ProgressGradients.h"
 #import "Torrent.h"
@@ -39,8 +39,8 @@
 #define NORMAL_BUTTON_WIDTH 14.0
 #define ACTION_BUTTON_WIDTH 16.0
 
-#define PRIORITY_ICON_WIDTH 14.0
-#define PRIORITY_ICON_HEIGHT 14.0
+#define PRIORITY_ICON_WIDTH 12.0
+#define PRIORITY_ICON_HEIGHT 12.0
 
 //ends up being larger than font height
 #define HEIGHT_TITLE 16.0
@@ -50,13 +50,14 @@
 #define PADDING_BETWEEN_BUTTONS 3.0
 #define PADDING_BETWEEN_IMAGE_AND_TITLE (PADDING_HORIZONTAL + 1.0)
 #define PADDING_BETWEEN_IMAGE_AND_BAR PADDING_HORIZONTAL
-#define PADDING_BETWEEN_TITLE_AND_PRIORITY 3.0
+#define PADDING_BETWEEN_TITLE_AND_PRIORITY 6.0
 #define PADDING_ABOVE_TITLE 4.0
 #define PADDING_BETWEEN_TITLE_AND_MIN_STATUS 3.0
 #define PADDING_BETWEEN_TITLE_AND_PROGRESS 1.0
 #define PADDING_BETWEEN_PROGRESS_AND_BAR 2.0
 #define PADDING_BETWEEN_BAR_AND_STATUS 2.0
 #define PADDING_BETWEEN_BAR_AND_EDGE_MIN 3.0
+#define PADDING_EXPANSION_FRAME 2.0
 
 #define PIECES_TOTAL_PERCENT 0.6
 
@@ -86,8 +87,6 @@
 - (NSString *) statusString;
 - (NSString *) minimalStatusString;
 
-- (void) drawImage: (NSImage *) image inRect: (NSRect) rect; //use until 10.5 dropped
-
 @end
 
 @implementation TorrentCell
@@ -210,20 +209,11 @@
         fMouseDownRevealButton = NO;
         [controlView setNeedsDisplayInRect: cellFrame];
         
-        if ([NSApp isOnSnowLeopardOrBetter])
+        NSString * location = [[self representedObject] dataLocation];
+        if (location)
         {
-            NSString * location = [[self representedObject] dataLocation];
-            if (location)
-            {
-                NSURL * file = [NSURL fileURLWithPath: location];
-                [[NSWorkspace sharedWorkspace] activateFileViewerSelectingURLs: [NSArray arrayWithObject: file]];
-            }
-        }
-        else
-        {
-            NSString * location = [[self representedObject] dataLocation];
-            if (location)
-                [[NSWorkspace sharedWorkspace] selectFile: location inFileViewerRootedAtPath: nil];
+            NSURL * file = [NSURL fileURLWithPath: location];
+            [[NSWorkspace sharedWorkspace] activateFileViewerSelectingURLs: [NSArray arrayWithObject: file]];
         }
     }
     else;
@@ -378,17 +368,17 @@
     //icon
     if (!minimal || !(!fTracking && fHoverAction)) //don't show in minimal mode when hovered over
     {
-        NSImage * icon = (minimal && error) ? [NSImage imageNamed: [NSApp isOnSnowLeopardOrBetter] ? NSImageNameCaution : @"Error.png"]
+        NSImage * icon = (minimal && error) ? [NSImage imageNamed: NSImageNameCaution]
                                             : [torrent icon];
-        [self drawImage: icon inRect: iconRect];
+        [icon drawInRect: iconRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0 respectFlipped: YES hints: nil];
     }
     
     //error badge
     if (error && !minimal)
     {
-        NSRect errorRect = NSMakeRect(NSMaxX(iconRect) - ERROR_IMAGE_SIZE, NSMaxY(iconRect) - ERROR_IMAGE_SIZE,
-                                        ERROR_IMAGE_SIZE, ERROR_IMAGE_SIZE);
-        [self drawImage: [NSImage imageNamed: [NSApp isOnSnowLeopardOrBetter] ? NSImageNameCaution : @"Error.png"] inRect: errorRect];
+        NSImage * errorImage = [NSImage imageNamed: NSImageNameCaution];
+        const NSRect errorRect = NSMakeRect(NSMaxX(iconRect) - ERROR_IMAGE_SIZE, NSMaxY(iconRect) - ERROR_IMAGE_SIZE, ERROR_IMAGE_SIZE, ERROR_IMAGE_SIZE);
+        [errorImage drawInRect: errorRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0 respectFlipped: YES hints: nil];
     }
     
     //text color
@@ -451,7 +441,7 @@
         }
         
         const NSRect controlRect = [self controlButtonRectForBounds: cellFrame];
-        [self drawImage: controlImage inRect: controlRect];
+        [controlImage drawInRect: controlRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0 respectFlipped: YES hints: nil];
         minimalTitleRightBound = MIN(minimalTitleRightBound, NSMinX(controlRect));
         
         //reveal button
@@ -464,7 +454,7 @@
             revealImageString = @"RevealOff.png";
         
         NSImage * revealImage = [NSImage imageNamed: revealImageString];
-        [self drawImage: revealImage inRect: [self revealButtonRectForBounds: cellFrame]];
+        [revealImage drawInRect: [self revealButtonRectForBounds: cellFrame] fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0 respectFlipped: YES hints: nil];
         
         //action button
         #warning image should use new gear
@@ -480,7 +470,7 @@
         if (actionImageString)
         {
             NSImage * actionImage = [NSImage imageNamed: actionImageString];
-            [self drawImage: actionImage inRect: [self actionButtonRectForBounds: cellFrame]];
+            [actionImage drawInRect: [self actionButtonRectForBounds: cellFrame] fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0 respectFlipped: YES hints: nil];
         }
     }
     
@@ -492,17 +482,13 @@
     //priority icon
     if ([torrent priority] != TR_PRI_NORMAL)
     {
-        NSImage * priorityImage = [torrent priority] == TR_PRI_HIGH ? [NSImage imageNamed: @"PriorityHigh.png"]
-                                                                    : [NSImage imageNamed: @"PriorityLow.png"];
-        //take line out completely when 10.6-only
-        priorityImage = [NSApp isOnSnowLeopardOrBetter] ? [priorityImage retain] : [priorityImage copy];
-        
         const NSRect priorityRect = NSMakeRect(NSMaxX(titleRect) + PADDING_BETWEEN_TITLE_AND_PRIORITY,
                                                NSMidY(titleRect) - PRIORITY_ICON_HEIGHT  * 0.5,
                                                PRIORITY_ICON_WIDTH, PRIORITY_ICON_HEIGHT);
         
-        [self drawImage: priorityImage inRect: priorityRect];
-        [priorityImage release];
+        NSColor * priorityColor = [self backgroundStyle] == NSBackgroundStyleDark ? [NSColor whiteColor] : [NSColor darkGrayColor];
+        NSImage * priorityImage = [[NSImage imageNamed: ([torrent priority] == TR_PRI_HIGH ? @"PriorityHighTemplate.png" : @"PriorityLowTemplate.png")] imageWithColor: priorityColor];
+        [priorityImage drawInRect: priorityRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0 respectFlipped: YES hints: nil];
     }
     
     //status
@@ -513,6 +499,50 @@
     }
 }
 
+- (NSRect) expansionFrameWithFrame: (NSRect) cellFrame inView: (NSView *) view
+{
+    BOOL minimal = [fDefaults boolForKey: @"SmallView"];
+    
+    //this code needs to match the code in drawInteriorWithFrame:withView:
+    CGFloat minimalTitleRightBound;
+    if (minimal)
+    {
+        NSAttributedString * minimalString = [self attributedStatusString: [self minimalStatusString]];
+        NSRect minimalStatusRect = [self rectForMinimalStatusWithString: minimalString inBounds: cellFrame];
+        
+        minimalTitleRightBound = NSMinX(minimalStatusRect);
+    }
+    
+    if (!minimal || fHover)
+    {
+        const NSRect controlRect = [self controlButtonRectForBounds: cellFrame];
+        minimalTitleRightBound = MIN(minimalTitleRightBound, NSMinX(controlRect));
+    }
+    
+    NSAttributedString * titleString = [self attributedTitle];
+    NSRect realRect = [self rectForTitleWithString: titleString withRightBound: minimalTitleRightBound inBounds: cellFrame];
+    
+    NSAssert([titleString size].width >= NSWidth(realRect), @"Full rect width should not be less than the used title rect width!");
+    
+    if ([titleString size].width > NSWidth(realRect)
+        && NSMouseInRect([view convertPoint: [[view window] convertScreenToBase: [NSEvent mouseLocation]] fromView: nil], realRect, [view isFlipped]))
+    {
+        realRect.size.width = [titleString size].width;
+        return NSInsetRect(realRect, -PADDING_EXPANSION_FRAME, -PADDING_EXPANSION_FRAME);
+    }
+    
+    return NSZeroRect;
+}
+
+- (void) drawWithExpansionFrame: (NSRect) cellFrame inView: (NSView *)view
+{
+    cellFrame.origin.x += PADDING_EXPANSION_FRAME;
+    cellFrame.origin.y += PADDING_EXPANSION_FRAME;
+    
+    NSAttributedString * titleString = [self attributedTitle];
+    [titleString drawInRect: cellFrame];
+}
+
 @end
 
 @implementation TorrentCell (Private)
@@ -522,7 +552,7 @@
     const BOOL minimal = [fDefaults boolForKey: @"SmallView"];
     
     const CGFloat piecesBarPercent = [(TorrentTableView *)[self controlView] piecesBarPercent];
-    if (piecesBarPercent > 0.0 && (!minimal || [NSApp isOnSnowLeopardOrBetter]))
+    if (piecesBarPercent > 0.0)
     {
         NSRect piecesBarRect, regularBarRect;
         NSDivideRect(barRect, &piecesBarRect, &regularBarRect, floor(NSHeight(barRect) * PIECES_TOTAL_PERCENT * piecesBarPercent),
@@ -660,11 +690,8 @@
     [torrent setPreviousFinishedPieces: [finishedIndexes count] > 0 ? finishedIndexes : nil]; //don't bother saving if none are complete
     
     //actually draw image
-    if ([NSApp isOnSnowLeopardOrBetter])
-        [bitmap drawInRect: barRect fromRect: NSZeroRect operation: NSCompositeSourceOver
-            fraction: ([fDefaults boolForKey: @"SmallView"] ? 0.25 : 1.0) respectFlipped: YES hints: nil];
-    else
-        [bitmap drawInRect: barRect];
+    [bitmap drawInRect: barRect fromRect: NSZeroRect operation: NSCompositeSourceOver
+        fraction: ([fDefaults boolForKey: @"SmallView"] ? 0.25 : 1.0) respectFlipped: YES hints: nil];
 
     [bitmap release];
 }
@@ -701,10 +728,8 @@
     }
     
     if ([(Torrent *)[self representedObject] priority] != TR_PRI_NORMAL)
-    {
         result.size.width -= PRIORITY_ICON_WIDTH + PADDING_BETWEEN_TITLE_AND_PRIORITY;
-        result.size.width = MIN(NSWidth(result), [string size].width); //only need to force it smaller for the priority icon
-    }
+    result.size.width = MIN(NSWidth(result), [string size].width);
     
     return result;
 }
@@ -802,7 +827,7 @@
 
 - (NSAttributedString *) attributedTitle
 {
-    NSString * title = [[self representedObject] name];
+    NSString * title = [(Torrent *)[self representedObject] name];
     return [[[NSAttributedString alloc] initWithString: title attributes: fTitleAttributes] autorelease];
 }
 
@@ -851,15 +876,4 @@
     return [fDefaults boolForKey: @"DisplaySmallStatusRegular"] ? [torrent shortStatusString] : [torrent remainingTimeString];
 }
 
-- (void) drawImage: (NSImage *) image inRect: (NSRect) rect
-{
-    if ([NSApp isOnSnowLeopardOrBetter])
-        [image drawInRect: rect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0 respectFlipped: YES hints: nil];
-    else
-    {
-        [image setFlipped: YES];
-        [image drawInRect: rect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0];
-    }
-}
-
 @end
