@@ -7,7 +7,7 @@
  *
  * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
  *
- * $Id: mainwin.h 11196 2010-09-06 00:19:37Z charles $
+ * $Id: mainwin.h 12611 2011-08-02 03:59:54Z jordan $
  */
 
 #ifndef MAIN_WINDOW_H
@@ -75,6 +75,8 @@ class TrMainWindow: public QMainWindow
         time_t myLastSendTime;
         time_t myLastReadTime;
         QTimer myNetworkTimer;
+        QTimer myRefreshTrayIconTimer;
+        QTimer myRefreshActionSensitivityTimer;
         QAction * myDlimitOffAction;
         QAction * myDlimitOnAction;
         QAction * myUlimitOffAction;
@@ -105,6 +107,7 @@ class TrMainWindow: public QMainWindow
         void refreshTitle( );
         void refreshStatusBar( );
         void refreshTrayIcon( );
+        void refreshTrayIconSoon( );
         void openTorrent( );
         void openURL( );
         void newTorrent( );
@@ -135,6 +138,7 @@ class TrMainWindow: public QMainWindow
         void onSortByETAToggled      ( bool );
         void onSortByNameToggled     ( bool );
         void onSortByProgressToggled ( bool );
+        void onSortByQueueToggled    ( bool );
         void onSortByRatioToggled    ( bool );
         void onSortBySizeToggled     ( bool );
         void onSortByStateToggled    ( bool );
@@ -158,11 +162,16 @@ class TrMainWindow: public QMainWindow
     public slots:
         void startAll( );
         void startSelected( );
+        void startSelectedNow( );
         void pauseAll( );
         void pauseSelected( );
         void removeSelected( );
         void deleteSelected( );
         void verifySelected( );
+        void queueMoveTop( );
+        void queueMoveUp( );
+        void queueMoveDown( );
+        void queueMoveBottom( );
         void reannounceSelected( );
         void addTorrent( const QString& filename );
         void onNetworkTimer( );
@@ -176,6 +185,7 @@ class TrMainWindow: public QMainWindow
         void setStatusbarVisible( bool );
         void setCompactView( bool );
         void refreshActionSensitivity( );
+        void refreshActionSensitivitySoon( );
         void wrongAuthentication( );
 
     public:
@@ -183,6 +193,7 @@ class TrMainWindow: public QMainWindow
         virtual ~TrMainWindow( );
 
     protected:
+        virtual void contextMenuEvent( QContextMenuEvent * );
         virtual void dragEnterEvent( QDragEnterEvent * );
         virtual void dropEvent( QDropEvent * );
 };
