@@ -7,7 +7,7 @@
  *
  * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
  *
- * $Id: options.cc 11112 2010-08-04 16:25:30Z charles $
+ * $Id: options.cc 12697 2011-08-20 05:19:27Z jordan $
  */
 
 #include <cstdio>
@@ -87,7 +87,7 @@ Options :: Options( Session& session, const Prefs& prefs, const AddData& addme,
     myVerifyHash( QCryptographicHash::Sha1 )
 
 {
-    setWindowTitle( tr( "Add Torrent" ) );
+    setWindowTitle( tr( "Open Torrent" ) );
     QFontMetrics fontMetrics( font( ) );
     QGridLayout * layout = new QGridLayout( this );
     int row = 0;
@@ -97,13 +97,13 @@ Options :: Options( Session& session, const Prefs& prefs, const AddData& addme,
     const QPixmap filePixmap = fileIcon.pixmap( iconSize );
 
     QPushButton * p;
-    int width = fontMetrics.size( 0, "This is a pretty long torrent filename indeed.torrent" ).width( );
+    int width = fontMetrics.size( 0, QString::fromAscii( "This is a pretty long torrent filename indeed.torrent" ) ).width( );
     QLabel * l = new QLabel( tr( "&Torrent file:" ) );
     layout->addWidget( l, row, 0, Qt::AlignLeft );
     p = myFileButton =  new QPushButton;
     p->setIcon( filePixmap );
     p->setMinimumWidth( width );
-    p->setStyleSheet( "text-align: left; padding-left: 5; padding-right: 5" );
+    p->setStyleSheet( QString::fromAscii( "text-align: left; padding-left: 5; padding-right: 5" ) );
     p->installEventFilter( this );
 
     layout->addWidget( p, row, 1 );
@@ -159,7 +159,7 @@ Options :: Options( Session& session, const Prefs& prefs, const AddData& addme,
     c->setChecked( prefs.getBool( Prefs :: TRASH_ORIGINAL ) );
     layout->addWidget( c, ++row, 0, 1, 2, Qt::AlignLeft );
 
-    QDialogButtonBox * b = new QDialogButtonBox( QDialogButtonBox::Ok|QDialogButtonBox::Cancel, Qt::Horizontal, this );
+    QDialogButtonBox * b = new QDialogButtonBox( QDialogButtonBox::Open|QDialogButtonBox::Cancel, Qt::Horizontal, this );
     connect( b, SIGNAL(rejected()), this, SLOT(deleteLater()) );
     connect( b, SIGNAL(accepted()), this, SLOT(onAccepted()) );
     layout->addWidget( b, ++row, 0, 1, 2 );
@@ -401,7 +401,7 @@ Options :: onFilenameClicked( )
     if( myAdd.type == AddData::FILENAME )
     {
         QFileDialog * d = new QFileDialog( this,
-                                           tr( "Add Torrent" ),
+                                           tr( "Open Torrent" ),
                                            QFileInfo(myAdd.filename).absolutePath(),
                                            tr( "Torrent Files (*.torrent);;All Files (*.*)" ) );
         d->setFileMode( QFileDialog::ExistingFile );
