@@ -7,7 +7,7 @@
  *
  * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
  *
- * $Id: prefs-dialog.h 11379 2010-11-02 01:24:08Z charles $
+ * $Id: prefs-dialog.h 12607 2011-08-01 22:24:24Z jordan $
  */
 
 #ifndef PREFS_DIALOG_H
@@ -41,11 +41,9 @@ class PrefsDialog: public QDialog
 
     private slots:
         void checkBoxToggled( bool checked );
-        void spinBoxChanged( int value );
-        void doubleSpinBoxChanged( double value );
-        void spinBoxChangedIdle( );
-        void timeChanged( const QTime& );
-        void textChanged( const QString& );
+        void spinBoxEditingFinished( );
+        void timeEditingFinished( );
+        void lineEditingFinished( );
         void refreshPref( int key );
         void encryptionEdited( int );
         void altSpeedDaysEdited( int );
@@ -80,6 +78,7 @@ class PrefsDialog: public QDialog
         void setPref( int key, const QVariant& v );
         bool isAllowed( int key ) const;
         QWidget * createTorrentsTab( );
+        QWidget * createDownloadTab( );
         QWidget * createSpeedTab( );
         QWidget * createPrivacyTab( );
         QWidget * createNetworkTab( );
