@@ -9,7 +9,12 @@
         <translation>Acerca de Transmission</translation>
     </message>
     <message>
-        <location line="+18"/>
+        <location line="+12"/>
+        <source>&lt;big&gt;Transmission %1&lt;/big&gt;</source>
+        <translation>&lt;big&gt;Transmission %1&lt;/big&gt;</translation>
+    </message>
+    <message>
+        <location line="+6"/>
         <source>A fast and easy BitTorrent client</source>
         <translation>Un cliente de bittorrent rápido y fácil</translation>
     </message>
@@ -37,7 +42,7 @@
 <context>
     <name>Details</name>
     <message>
-        <location filename="../details.cc" line="+151"/>
+        <location filename="../details.cc" line="+153"/>
         <source>Torrent Properties</source>
         <translation>Propiedades del Torrent</translation>
     </message>
@@ -68,7 +73,7 @@
         <translation>Opciones</translation>
     </message>
     <message>
-        <location line="+144"/>
+        <location line="+176"/>
         <source>None</source>
         <translation>Ninguno</translation>
     </message>
@@ -79,12 +84,12 @@
     </message>
     <message>
         <location line="+1"/>
-        <location line="+181"/>
+        <location line="+175"/>
         <source>Unknown</source>
         <translation>Desconocido</translation>
     </message>
     <message>
-        <location line="-149"/>
+        <location line="-143"/>
         <source>Finished</source>
         <translation>Terminado</translation>
     </message>
@@ -94,27 +99,7 @@
         <translation>Detenido</translation>
     </message>
     <message>
-        <location line="+42"/>
-        <source>%1 (%2%)</source>
-        <translation>%1 (%2%)</translation>
-    </message>
-    <message>
-        <location line="+6"/>
-        <source>%1 (%2% of %3% Available)</source>
-        <translation>%1 (%2% de %3% disponible)</translation>
-    </message>
-    <message>
-        <location line="+7"/>
-        <source>%1 (%2% of %3% Available) + %4 Unverified</source>
-        <translation>%1 (%2% de %3% disponible) + %4 Sin verificar</translation>
-    </message>
-    <message>
-        <location line="+33"/>
-        <source>%1 (+%2 corrupt)</source>
-        <translation>%1 (+%2 corrupto)</translation>
-    </message>
-    <message>
-        <location line="+15"/>
+        <location line="+97"/>
         <source>%1 (Ratio: %2)</source>
         <translatorcomment>Fracción</translatorcomment>
         <translation>%1 (Proporción: %2)</translation>
@@ -177,7 +162,7 @@
         <translation>Creado por %1 el %2</translation>
     </message>
     <message>
-        <location line="+139"/>
+        <location line="+121"/>
         <location line="+21"/>
         <source>Encrypted connection</source>
         <translation>Conexión cifrada</translation>
@@ -232,18 +217,38 @@
         <source>Peer is an incoming connection</source>
         <translation>El compañero es una conexión de entrada</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Peer is connected over uTP</source>
+        <translation>Compañero conectado usando uTP</translation>
+    </message>
     <message>
         <location line="+56"/>
         <source>Activity</source>
         <translation>Actividad</translation>
     </message>
     <message>
-        <location line="+1"/>
-        <source>Torrent size:</source>
-        <translation>Tamaño del torrent:</translation>
+        <location line="-445"/>
+        <source>%1 (100%)</source>
+        <translation></translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="+5"/>
+        <source>%1 of %2 (%3%)</source>
+        <translation>%1 de %2 (%3%)</translation>
+    </message>
+    <message>
+        <location line="+7"/>
+        <source>%1 of %2 (%3%), %4 Unverified</source>
+        <translation>%1 de %2 (%3%), %4 Sin verificar</translation>
+    </message>
+    <message>
+        <location line="+33"/>
+        <source>%1 (%2 corrupt)</source>
+        <translation>%1 (%2 corrupto)</translation>
+    </message>
+    <message>
+        <location line="+401"/>
         <source>Have:</source>
         <translation>Tenemos:</translation>
     </message>
@@ -292,6 +297,11 @@
         <source>Details</source>
         <translation>Detalles</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Size:</source>
+        <translation>Tamaño:</translation>
+    </message>
     <message>
         <location line="+1"/>
         <source>Location:</source>
@@ -318,7 +328,7 @@
         <translation>Comentario:</translation>
     </message>
     <message>
-        <location line="+116"/>
+        <location line="+96"/>
         <source>Add URL </source>
         <translation>Agregar URL </translation>
     </message>
@@ -371,12 +381,12 @@
         <translation>Limitar velocidad de &amp;descarga (%1):</translation>
     </message>
     <message>
-        <location line="+11"/>
+        <location line="+12"/>
         <source>Limit &amp;upload speed (%1):</source>
         <translation>Limitar velocidad de &amp;carga (%1):</translation>
     </message>
     <message>
-        <location line="+12"/>
+        <location line="+13"/>
         <source>High</source>
         <translation>Alta</translation>
     </message>
@@ -402,12 +412,12 @@
     </message>
     <message>
         <location line="+5"/>
-        <location line="+14"/>
+        <location line="+15"/>
         <source>Use Global Settings</source>
         <translation>Usar Configuración Global</translation>
     </message>
     <message>
-        <location line="-13"/>
+        <location line="-14"/>
         <source>Seed regardless of ratio</source>
         <translation>Compartir sin importar proporción</translation>
     </message>
@@ -417,7 +427,7 @@
         <translation>Dejar de compartir llegando a proporción:</translation>
     </message>
     <message>
-        <location line="+7"/>
+        <location line="+8"/>
         <source>&amp;Ratio:</source>
         <translation>&amp;Proporción:</translation>
     </message>
@@ -432,7 +442,7 @@
         <translation>Dejar de compartir si está inactivo N minutos:</translation>
     </message>
     <message>
-        <location line="+8"/>
+        <location line="+9"/>
         <source>&amp;Idle:</source>
         <translation>&amp;Inactivo:</translation>
     </message>
@@ -442,7 +452,7 @@
         <translation>Conexiones de compañeros</translation>
     </message>
     <message>
-        <location line="+7"/>
+        <location line="+8"/>
         <source>&amp;Maximum peers:</source>
         <translation>&amp;Máximo no. de compañeros:</translation>
     </message>
@@ -545,12 +555,12 @@
     <name>FilterBar</name>
     <message>
         <location filename="../filterbar.cc" line="+223"/>
-        <location line="+151"/>
+        <location line="+157"/>
         <source>All</source>
         <translation>Todos</translation>
     </message>
     <message>
-        <location line="-144"/>
+        <location line="-150"/>
         <source>Active</source>
         <translation>Activos</translation>
     </message>
@@ -574,11 +584,6 @@
         <source>Finished</source>
         <translation>Terminados</translation>
     </message>
-    <message>
-        <location line="+4"/>
-        <source>Queued</source>
-        <translation>En cola</translation>
-    </message>
     <message>
         <location line="+4"/>
         <source>Verifying</source>
@@ -590,7 +595,7 @@
         <translation>Error</translation>
     </message>
     <message>
-        <location line="+147"/>
+        <location line="+157"/>
         <source>Show:</source>
         <translation>Mostrar:</translation>
     </message>
@@ -654,7 +659,13 @@
     </message>
     <message>
         <location line="+32"/>
-        <location line="+12"/>
+        <location line="+14"/>
+        <source>Unknown</source>
+        <translation>Desconocido</translation>
+    </message>
+    <message>
+        <location line="-12"/>
+        <location line="+14"/>
         <location line="+12"/>
         <source>None</source>
         <translation>Nada</translation>
@@ -720,7 +731,7 @@
         <translation>&amp;Torrent</translation>
     </message>
     <message>
-        <location line="+19"/>
+        <location line="+30"/>
         <source>&amp;Edit</source>
         <translation>&amp;Editar</translation>
     </message>
@@ -735,7 +746,7 @@
         <translation>&amp;Ver</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+22"/>
         <source>&amp;File</source>
         <translation>&amp;Archivo</translation>
     </message>
@@ -745,27 +756,7 @@
         <translation>Barra de Herramientas</translation>
     </message>
     <message>
-        <location line="+35"/>
-        <source>&amp;Add File...</source>
-        <translation>&amp;Agregar Archivo...</translation>
-    </message>
-    <message>
-        <location line="+3"/>
-        <source>Add</source>
-        <translation>Agregar</translation>
-    </message>
-    <message>
-        <location line="+3"/>
-        <source>Add a torrent</source>
-        <translation>Agregar un torrent</translation>
-    </message>
-    <message>
-        <location line="+3"/>
-        <source>Ctrl+D</source>
-        <translation>Ctrl+D</translation>
-    </message>
-    <message>
-        <location line="+5"/>
+        <location line="+49"/>
         <source>&amp;New...</source>
         <translation>&amp;Nuevo...</translation>
     </message>
@@ -795,20 +786,45 @@
         <translation>Alt+Enter</translation>
     </message>
     <message>
-        <location line="+5"/>
-        <source>&amp;Open Folder</source>
-        <translation>Abrir &amp;Folder</translation>
-    </message>
-    <message>
-        <location line="+3"/>
+        <location line="+8"/>
         <source>Open the torrent&apos;s folder</source>
         <translation>Abrir el folder del torrent</translation>
     </message>
     <message>
-        <location line="+3"/>
+        <location line="-30"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
+    <message>
+        <location line="-133"/>
+        <source>Queue</source>
+        <translation>Cola</translation>
+    </message>
+    <message>
+        <location line="+124"/>
+        <source>&amp;Open...</source>
+        <translation>&amp;Abrir...</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Open</source>
+        <translation>Abrir</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Open a torrent</source>
+        <translation>Abrir el archivo</translation>
+    </message>
+    <message>
+        <location line="+30"/>
+        <source>Open Fold&amp;er</source>
+        <translation>Abrir la &amp;carpeta</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>Ctrl+E</source>
+        <translation></translation>
+    </message>
     <message>
         <location line="+5"/>
         <source>&amp;Start</source>
@@ -859,6 +875,11 @@
         <source>Verify local data</source>
         <translation>Verificar los datos locales</translation>
     </message>
+    <message>
+        <location line="+3"/>
+        <source>Ctrl+V</source>
+        <translation></translation>
+    </message>
     <message>
         <location line="+5"/>
         <source>&amp;Remove</source>
@@ -1108,19 +1129,64 @@
     </message>
     <message>
         <location line="+5"/>
-        <source>Add &amp;URL...</source>
-        <translation>Agregar &amp;URL...</translation>
+        <source>Open &amp;URL...</source>
+        <translation>Abrir &amp;URL...</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Ctrl+U</source>
+        <translation></translation>
     </message>
     <message>
         <location line="+5"/>
         <source>&amp;Donate</source>
         <translation>&amp;Donar</translation>
     </message>
+    <message>
+        <location line="+5"/>
+        <source>Start &amp;Now</source>
+        <translation>Arranca &amp;Ahora</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Bypass the queue and start now</source>
+        <translation>Salta la cola y arranco ahora</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Ctrl+Shift+S</source>
+        <translation>Ctrl+Shift+S</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>Move to &amp;Top</source>
+        <translation>Mover al &amp;principio</translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>Move &amp;Up</source>
+        <translation>Mover hacia &amp;arriba</translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>Move &amp;Down</source>
+        <translation>Mover hacia a&amp;bajo</translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>Move to &amp;Bottom</source>
+        <translation>Mover al &amp;final</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>Sort by &amp;Queue</source>
+        <translation>Ordenar por &amp;cola</translation>
+    </message>
 </context>
 <context>
     <name>MakeDialog</name>
     <message>
-        <location filename="../make-dialog.cc" line="+85"/>
+        <location filename="../make-dialog.cc" line="+86"/>
         <source>Creating &quot;%1&quot;</source>
         <translation>Creando &quot;%1&quot;</translation>
     </message>
@@ -1151,7 +1217,7 @@
     </message>
     <message>
         <location line="+33"/>
-        <location line="+194"/>
+        <location line="+196"/>
         <source>New Torrent</source>
         <translation>Nuevo torrent</translation>
     </message>
@@ -1249,7 +1315,7 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
 <context>
     <name>MyApp</name>
     <message>
-        <location filename="../app.cc" line="+218"/>
+        <location filename="../app.cc" line="+227"/>
         <source>Transmission is a file-sharing program.  When you run a torrent, its data will be made available to others by means of upload.  You and you alone are fully responsible for exercising proper judgement and abiding by your local laws.</source>
         <translation>Transmission es un programa para compartir archivos.  Cuando activas un torrent, sus datos van a ponerse disponibles para otros.  Usted y sólo usted es completamente responsable para usar su juicio y cumplir las leyes locales.</translation>
     </message>
@@ -1264,7 +1330,12 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
         <translation>Yo &amp;acepto</translation>
     </message>
     <message>
-        <location line="+50"/>
+        <location line="+53"/>
+        <source>Torrent Completed</source>
+        <translation>Torrent completado</translation>
+    </message>
+    <message>
+        <location line="+15"/>
         <source>Torrent Added</source>
         <translation>Torrent añadido</translation>
     </message>
@@ -1274,8 +1345,8 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
     <message>
         <location filename="../options.cc" line="+22"/>
         <location line="+314"/>
-        <source>Add Torrent</source>
-        <translation>Agregar torrent</translation>
+        <source>Open Torrent</source>
+        <translation>Abrir Torrent</translation>
     </message>
     <message>
         <location line="-303"/>
@@ -1336,7 +1407,7 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
 <context>
     <name>PrefsDialog</name>
     <message>
-        <location filename="../prefs-dialog.cc" line="+197"/>
+        <location filename="../prefs-dialog.cc" line="+175"/>
         <source>Web Client</source>
         <translation>Cliente de Web</translation>
     </message>
@@ -1482,12 +1553,12 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
     </message>
     <message>
         <location line="+18"/>
-        <location line="+302"/>
+        <location line="+334"/>
         <source>Desktop</source>
         <translation>Escritorio</translation>
     </message>
     <message>
-        <location line="-300"/>
+        <location line="-332"/>
         <source>Show Transmission icon in the &amp;notification area</source>
         <translation>Mostrar ícono de Transmission en el área de &amp;notificaciones</translation>
     </message>
@@ -1508,8 +1579,8 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
     </message>
     <message>
         <location line="+6"/>
-        <source>Testing...</source>
-        <translation>Probando...</translation>
+        <source>Testing TCP Port...</source>
+        <translation>Probando puerto TCP...</translation>
     </message>
     <message>
         <location line="+10"/>
@@ -1524,12 +1595,12 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
     </message>
     <message>
         <location line="+1"/>
-        <location line="+358"/>
+        <location line="+397"/>
         <source>Status unknown</source>
         <translation>Estado desconocido</translation>
     </message>
     <message>
-        <location line="-350"/>
+        <location line="-389"/>
         <source>&amp;Port for incoming connections:</source>
         <translation>&amp;Puerto para recibir conexiones:</translation>
     </message>
@@ -1558,6 +1629,21 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
         <source>Maximum peers &amp;overall:</source>
         <translation>Máximo número de compañeros &amp;global:</translation>
     </message>
+    <message>
+        <location line="+3"/>
+        <source>Options</source>
+        <translation>Opciones</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Enable &amp;uTP for peer connections</source>
+        <translation>Habilitar uTP en conexiones de compañeros</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>uTP is a tool for reducing network congestion.</source>
+        <translation>uTP es una herramienta para reducir la congestión en redes.</translation>
+    </message>
     <message numerus="yes">
         <location line="+28"/>
         <source>&lt;b&gt;Update succeeded!&lt;/b&gt;&lt;p&gt;Blocklist now has %Ln rules.</source>
@@ -1593,12 +1679,12 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
     </message>
     <message>
         <location line="+5"/>
-        <location line="+162"/>
+        <location line="+187"/>
         <source>Privacy</source>
         <translation>Privacia</translation>
     </message>
     <message>
-        <location line="-159"/>
+        <location line="-184"/>
         <source>Allow encryption</source>
         <translation>Permitir cifrado</translation>
     </message>
@@ -1673,12 +1759,12 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
         <translation>Al agregar</translation>
     </message>
     <message>
-        <location line="+2"/>
+        <location line="+6"/>
         <source>Automatically &amp;add torrents from:</source>
         <translation>&amp;Agregar torrents automáticamente de:</translation>
     </message>
     <message>
-        <location line="+8"/>
+        <location line="-4"/>
         <source>Show &amp;options dialog</source>
         <translation>Mostrar dialogo de &amp;opciones</translation>
     </message>
@@ -1693,22 +1779,17 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
         <translation>Mo&amp;ver archivo .torrent a la basura</translation>
     </message>
     <message>
-        <location line="+3"/>
-        <source>Downloading</source>
-        <translation>Al descargar</translation>
-    </message>
-    <message>
-        <location line="+2"/>
+        <location line="+56"/>
         <source>Append &quot;.&amp;part&quot; to incomplete files&apos; names</source>
         <translation>Agregar .&amp;part al nombre de archivos incompletos</translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="-11"/>
         <source>Save to &amp;Location:</source>
         <translation>Guardar en &amp;locación:</translation>
     </message>
     <message>
-        <location line="+2"/>
+        <location line="+13"/>
         <source>Keep &amp;incomplete files in:</source>
         <translation>Mantener archivos &amp;incompletos en:</translation>
     </message>
@@ -1718,7 +1799,7 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
         <translation>Ejecutar scrip&amp;t cuando el torrent esté completo:</translation>
     </message>
     <message>
-        <location line="+9"/>
+        <location line="-55"/>
         <source>Seeding Limits</source>
         <translation>Límites para compartir</translation>
     </message>
@@ -1733,7 +1814,33 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
         <translation>Dejar de compartir si está inactivo &amp;N minutos:</translation>
     </message>
     <message>
-        <location line="+20"/>
+        <location line="+21"/>
+        <source>Location</source>
+        <translation>Localización</translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>Queue</source>
+        <translatorcomment>Fila</translatorcomment>
+        <translation>Cola</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Maximum active &amp;downloads:</source>
+        <translation>Máx.&amp;descargas activas:</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Downloads sharing data in the last N minutes are &amp;active:</source>
+        <translation>Descargas compartiendo en los últimos N minutos se consideran &amp;activas:</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Incomplete</source>
+        <translation>Incompleto</translation>
+    </message>
+    <message>
+        <location line="+35"/>
         <source>Transmission Preferences</source>
         <translation>Preferencias del programa</translation>
     </message>
@@ -1742,6 +1849,11 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
         <source>Torrents</source>
         <translation>Torrents</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Download</source>
+        <translation>Descarga</translation>
+    </message>
     <message>
         <location line="+1"/>
         <source>Speed</source>
@@ -1758,23 +1870,23 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
         <translation>Web</translation>
     </message>
     <message>
-        <location line="+27"/>
+        <location line="+28"/>
         <source>Not supported by remote sessions</source>
         <translation>No soportado por sesiones remotas</translation>
     </message>
     <message numerus="yes">
         <location line="+31"/>
-        <source>&lt;i&gt;Blocklist contains %Ln rules)</source>
+        <source>&lt;i&gt;Blocklist contains %Ln rules&lt;/i&gt;</source>
         <translation>
-            <numerusform>&lt;i&gt;La lista de bloqueos contiene %n regla)</numerusform>
-            <numerusform>&lt;i&gt;La lista de bloqueos contiene %Ln reglas)</numerusform>
+            <numerusform>&lt;i&gt;Lista de bloqueos contiene %Ln reglas&lt;/i&gt;</numerusform>
+            <numerusform></numerusform>
         </translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../app.cc" line="-140"/>
+        <location filename="../app.cc" line="-163"/>
         <source>Invalid option</source>
         <translation>Opción inválida</translation>
     </message>
@@ -1815,7 +1927,7 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
 <context>
     <name>Session</name>
     <message>
-        <location filename="../session.cc" line="+785"/>
+        <location filename="../session.cc" line="+797"/>
         <source>Add Torrent</source>
         <translation>Agregar torrent</translation>
     </message>
@@ -1923,27 +2035,22 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
 <context>
     <name>Torrent</name>
     <message>
-        <location filename="../torrent.cc" line="+686"/>
-        <source>Waiting to verify local data</source>
-        <translation>Esperando para verificar datos locales</translation>
-    </message>
-    <message>
-        <location line="+1"/>
+        <location filename="../torrent.cc" line="+708"/>
         <source>Verifying local data</source>
         <translation>Verificando datos locales</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="+2"/>
         <source>Downloading</source>
         <translation>Descargando</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="+2"/>
         <source>Seeding</source>
         <translation>Compartiendo</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="-6"/>
         <source>Finished</source>
         <translation>Terminado</translation>
     </message>
@@ -1953,7 +2060,23 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
         <translation>Detenido</translation>
     </message>
     <message>
-        <location line="+13"/>
+        <location line="+1"/>
+        <source>Queued for verification</source>
+        <translatorcomment>Esperando verificación</translatorcomment>
+        <translation>En cola para verificación</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Queued for download</source>
+        <translation>En cola para descarga</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Queued for seeding</source>
+        <translation>En cola para carga</translation>
+    </message>
+    <message>
+        <location line="+14"/>
         <source>Tracker gave a warning: %1</source>
         <translation>El seguidor dió una advertencia: %1</translation>
     </message>
@@ -2002,12 +2125,12 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
     </message>
     <message>
         <location line="+10"/>
-        <location line="+102"/>
+        <location line="+106"/>
         <source> - </source>
         <translation> - </translation>
     </message>
     <message>
-        <location line="-100"/>
+        <location line="-104"/>
         <source>%1 left</source>
         <translation>falta %1</translation>
     </message>
@@ -2027,6 +2150,11 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
         <source>%1 %2</source>
         <translation>%1 %2</translation>
     </message>
+    <message>
+        <location line="+2"/>
+        <source>Stalled</source>
+        <translation>Atorado</translation>
+    </message>
     <message>
         <location line="+2"/>
         <source>Idle</source>
@@ -2043,7 +2171,7 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
         <translation>Proporción: %1, </translation>
     </message>
     <message numerus="yes">
-        <location line="+31"/>
+        <location line="+33"/>
         <source>Downloading from %1 of %n connected peer(s)</source>
         <translation>
             <numerusform>Descargando desde %1 de %n compañero conectado</numerusform>
@@ -2066,11 +2194,16 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
             <numerusform>Compartiendo a %1 de %n compañeros conectados</numerusform>
         </translation>
     </message>
+    <message>
+        <location line="+5"/>
+        <source>Error</source>
+        <translation>Error</translation>
+    </message>
 </context>
 <context>
     <name>TrMainWindow</name>
     <message>
-        <location filename="../mainwin.cc" line="+450"/>
+        <location filename="../mainwin.cc" line="+446"/>
         <source>Limit Download Speed</source>
         <translation>Limitar velocidad de descarga</translation>
     </message>
@@ -2083,13 +2216,13 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
     <message>
         <location line="-15"/>
         <location line="+20"/>
-        <location line="+448"/>
+        <location line="+502"/>
         <location line="+8"/>
         <source>Limited at %1</source>
         <translation>Limitada a %1</translation>
     </message>
     <message>
-        <location line="-464"/>
+        <location line="-518"/>
         <source>Limit Upload Speed</source>
         <translation>Limitar velocidad de carga</translation>
     </message>
@@ -2106,12 +2239,12 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
     </message>
     <message>
         <location line="+5"/>
-        <location line="+442"/>
+        <location line="+496"/>
         <source>Stop at Ratio (%1)</source>
         <translation>Detener a la proporción (%1)</translation>
     </message>
     <message>
-        <location line="-318"/>
+        <location line="-371"/>
         <source> - %1:%2</source>
         <translation> - %1:%2</translation>
     </message>
@@ -2132,7 +2265,7 @@ Para agregar otro URL primario, agrueguelo después de una línea en blanco.</tr
         </translation>
     </message>
     <message>
-        <location line="+9"/>
+        <location line="+18"/>
         <source>Idle</source>
         <translation>Sin cambio</translation>
     </message>
@@ -2158,7 +2291,7 @@ Bajada: %2</translation>
         <translation>Bajada: %1, Subida: %2</translation>
     </message>
     <message>
-        <location line="+315"/>
+        <location line="+359"/>
         <source>Click to disable Temporary Speed Limits
 (%1 down, %2 up)</source>
         <translation>Presione para deshabilitar límites temporales de velocidad
@@ -2173,11 +2306,22 @@ Bajada: %2</translation>
     </message>
     <message>
         <location line="+29"/>
-        <source>Add Torrent</source>
-        <translation>Agregar torrent</translation>
+        <source>Open Torrent</source>
+        <translation>Abrir Torrent</translation>
     </message>
     <message>
-        <location line="+2"/>
+        <location line="+36"/>
+        <location line="+1"/>
+        <source>Open URL or Magnet Link</source>
+        <translation>Abrir URL o Liga Magnetizada</translation>
+    </message>
+    <message>
+        <location line="+224"/>
+        <source>Queue</source>
+        <translation>Cola</translation>
+    </message>
+    <message>
+        <location line="-259"/>
         <source>Torrent Files (*.torrent);;All Files (*.*)</source>
         <translation>Archivos de torrent (*.torrent);;Todos los archivos (*.*)</translation>
     </message>
@@ -2187,14 +2331,7 @@ Bajada: %2</translation>
         <translation>Mostar diálogo de &amp;opciones</translation>
     </message>
     <message>
-        <location line="+24"/>
-        <location line="+1"/>
-        <source>Add URL or Magnet Link</source>
-        <translatorcomment>imantada</translatorcomment>
-        <translation>Agregar URL o liga magnetizada</translation>
-    </message>
-    <message>
-        <location line="+55"/>
+        <location line="+87"/>
         <source>Remove torrent?</source>
         <translation>¿Remover torrent?</translation>
     </message>
